@@ -74,6 +74,11 @@ pulse.  Only applies when `pulsar-pulse' is non-nil."
     bookmark-jump
     delete-other-windows
     delete-window
+    dired-maybe-insert-subdir
+    dired-up-directory
+    dired-goto-file
+    dired-next-dirline
+    dired-prev-dirline
     evil-goto-first-line
     evil-goto-line
     evil-scroll-down
@@ -86,6 +91,7 @@ pulse.  Only applies when `pulsar-pulse' is non-nil."
     forward-page
     goto-line
     handle-switch-frame
+    imenu
     logos-backward-page-dwim
     logos-forward-page-dwim
     handle-select-window
@@ -94,7 +100,10 @@ pulse.  Only applies when `pulsar-pulse' is non-nil."
     narrow-to-page
     narrow-to-region
     next-buffer
+    next-error
+    next-error-recenter
     next-multiframe-window
+    occur-mode-goto-occurrence
     org-backward-heading-same-level
     org-forward-heading-same-level
     org-next-visible-heading
@@ -106,6 +115,7 @@ pulse.  Only applies when `pulsar-pulse' is non-nil."
     outline-previous-visible-heading
     outline-up-heading
     previous-buffer
+    previous-error
     recenter-top-bottom
     reposition-window
     scroll-down-command
